# xlsx2csv
Command line utility to convert xlsx file to csv

Heavily based off [Caleb Dinsmore's](https://github.com/calebdinsmore) command line utility [matillion-columns](https://github.com/calebdinsmore/matillion-columns).
